==> musashi-core-1.0.3.tar.gz: musashi-core-1.0.3/help/en/xtnjoinHelp.h <==

#include "commonHelp.h"
/*============================================================================*/
/* ޥɥإ,man,musahi GUI ̥å                           */
/*============================================================================*/
/*----------------------------------------------------------------------------*/
/* ޥɤΥȥ                                                         */
/* ޥɥإפκǽιԤɽ                                             */
/*----------------------------------------------------------------------------*/
#define HELPT "natural join operation"

/*----------------------------------------------------------------------------*/
/* ѥ᡼                                                                 */
/* ޥɥإפ USAGE:Ȥ" XXXT"ɽ ex)-k ̾ꥹ*/
/* flagΥץϥޥɥإפOPTIONS)Ȥɽ ex)-z : ɸϤΰ*/
/*----------------------------------------------------------------------------*/
/*-k*/
#define TKYT "list of attributes"
#define TKYC "a list of attributes based on which join is done (mandatory)"

/*-K*/
#define MKYT "list of attributes"
#define MKYC "a list of attributes of a reference file. This is used when the attribute names of a reference file are different from those of an input file specified by -k."

/*-m*/
#define MSTT "reference file"
#define MSTC "name of the reference file"

/*-f*/
#define FLDT "list of attributes"
#define FLDC "the  attribute of a reference file which is joined with an input file"
#define FLDF NULL

/*-n*/
#define TNLT "input data not matched"
#define TNLC "flag indicating that input data which does not match the reference file is also output"

/*-N*/
#define MNLT "reference data not macthed"
#define MNLC "flag indicating that data of a reference file which does not match the input file is also output"

/*-H*/
#define HAST "hash join"
#define HASC "hash join is performed with this option"

/*-i*/
#define INFT C_INFT
#define INFC C_INFC

/*-o*/
#define OTFT C_OTFT
#define OTFC C_OTFC

/*-z*/
#define ZIPT C_ZIPT
#define ZIPC C_ZIPC

/*-t*/
#define TXTT C_TXTT
#define TXTC C_TXTC

/*-T*/
#define TMPT C_TMPT
#define TMPC C_TMPC

/*----------------------------------------------------------------------------*/
/*                                                                        */
/* ޥɥإפSUMMARY:Ȥɽ                                     */
/* HTMLإפmanˤϡHELPDξ˷礹ɽ                   */
/*----------------------------------------------------------------------------*/
#define HELPS "This command is the same as xtjoin except that the attribute of a reference file specified by -K does not need to take the unique value. See xtjoin for the details. "

/*----------------------------------------------------------------------------*/
/*                                                                          */
/*----------------------------------------------------------------------------*/
#define HELPE "\
xtnjoin -k customerID -m ref.xt -f birthday,gender -i dat.xt -o rsl.xt\n\
xtnjoin -k customerID -m ref.xt -f birthday,gender -nN -i dat.xt -o rsl.xt\n\
"

/*----------------------------------------------------------------------------*/
/* ȥޥ(ɬޤǶڤꡢѤʤ)                           */
/*----------------------------------------------------------------------------*/
#define HELPR "xtjoin,xtproduct,xtcommon"

/*----------------------------------------------------------------------------*/
/* ԤˤĤ                                                               */
/* ޥɥإפˤɽʤ                                             */
/*----------------------------------------------------------------------------*/
#define HELPA C_HELPA

/*----------------------------------------------------------------------------*/
/* Хݡ                                                               */
/* ϿХޥɥإפBUG REPORT:ɽ롣                  */
/* Ͽʤ(#define HELPB "")ɽʤ                           */
/*----------------------------------------------------------------------------*/
#define HELPB C_HELPB

/*----------------------------------------------------------------------------*/
/* ۡڡ                                                               */
/* ϿХޥɥإפINFORMATION:ɽ롣                 */
/* Ͽʤ(#define HELPH "")ɽʤ                           */
/*----------------------------------------------------------------------------*/
#define HELPH C_HELPH

==> musashi-core-1.0.4.tar.gz: musashi-core-1.0.4/help/en/xtnjoinHelp.h <==
#include "commonHelp.h"
/*============================================================================*/
/* Management of messages common to command help, man, and musashi GUI                           */
/*============================================================================*/
/*----------------------------------------------------------------------------*/
/* ޥɤΥȥ                                                         */
/* ޥɥإפκǽιԤɽ                                             */
/*----------------------------------------------------------------------------*/
#define HELPT "natural join operation"

/*----------------------------------------------------------------------------*/
/* ѥ᡼                                                                 */
/* ޥɥإפ USAGE:Ȥ" XXXT"ɽ ex)-k ̾ꥹ*/
/* flagΥץϥޥɥإפOPTIONS)Ȥɽ ex)-z : ɸϤΰ*/
/*----------------------------------------------------------------------------*/
/*-k*/
#define TKYT "list of attributes"
#define TKYC "a list of attributes based on which join is done (mandatory)"

/*-K*/
#define MKYT "list of attributes"
#define MKYC "a list of attributes of a reference file. This is used when the attribute names of a reference file are different from those of an input file specified by -k."

/*-m*/
#define MSTT "reference file"
#define MSTC "name of the reference file"

/*-f*/
#define FLDT "list of attributes"
#define FLDC "the  attribute of a reference file which is joined with an input file"
#define FLDF NULL

/*-n*/
#define TNLT "input data not matched"
#define TNLC "flag indicating that input data which does not match the reference file is also output"

/*-N*/
#define MNLT "reference data not macthed"
#define MNLC "flag indicating that data of a reference file which does not match the input file is also output"

/*-H*/
#define HAST "hash join"
#define HASC "hash join is performed with this option"

/*-i*/
#define INFT C_INFT
#define INFC C_INFC

/*-o*/
#define OTFT C_OTFT
#define OTFC C_OTFC

/*-z*/
#define ZIPT C_ZIPT
#define ZIPC C_ZIPC

/*-t*/
#define TXTT C_TXTT
#define TXTC C_TXTC

/*-T*/
#define TMPT C_TMPT
#define TMPC C_TMPC

/*----------------------------------------------------------------------------*/
/*                                                                        */
/* ޥɥإפSUMMARY:Ȥɽ                                     */
/* HTMLإפmanˤϡHELPDξ˷礹ɽ                   */
/*----------------------------------------------------------------------------*/
#define HELPS "The notion of this command is the same as xtjoin except that the key attribute in the reference file -K need not be an unique value. Please refer to xtjoin for more details. "

/*----------------------------------------------------------------------------*/
/*                                                                          */
/*----------------------------------------------------------------------------*/
#define HELPE "\
xtnjoin -k customerID -m ref.xt -f birthday,gender -i dat.xt -o rsl.xt\n\
xtnjoin -k customerID -m ref.xt -f birthday,gender -nN -i dat.xt -o rsl.xt\n\
"

/*----------------------------------------------------------------------------*/
/* ȥޥ(ɬޤǶڤꡢѤʤ)                           */
/*----------------------------------------------------------------------------*/
#define HELPR "xtjoin,xtproduct,xtcommon"

/*----------------------------------------------------------------------------*/
/* ԤˤĤ                                                               */
/* ޥɥإפˤɽʤ                                             */
/*----------------------------------------------------------------------------*/
#define HELPA C_HELPA

/*----------------------------------------------------------------------------*/
/* Хݡ                                                               */
/* ϿХޥɥإפBUG REPORT:ɽ롣                  */
/* Ͽʤ(#define HELPB "")ɽʤ                           */
/*----------------------------------------------------------------------------*/
#define HELPB C_HELPB

/*----------------------------------------------------------------------------*/
/* ۡڡ                                                               */
/* ϿХޥɥإפINFORMATION:ɽ롣                 */
/* Ͽʤ(#define HELPH "")ɽʤ                           */
/*----------------------------------------------------------------------------*/
#define HELPH C_HELPH
